| car_color_palettes | R Documentation |
This function includes color palettes of car companies that previous decades. More color palettes will be added in the future.
car_color_palettes
name |
Name of the color palette. |
n |
The amount of colors desired for your plot. |
An object of class list of length 3.
A vector of colors.
car_color("datsun1", 4)
car_color("datsun2")
library(tidyverse)
mtcars %>%
ggplot(aes(hp, mpg)) +
geom_point(aes(color = as.factor(cyl))) +
scale_color_manual(values = car_color("datsun1"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.